.ts-dropdown-content {
    max-height: 300px;
}

/* Use the theme's primary color as box-shadow colour */
.plugin-dropdown_input.focus .ts-dropdown .dropdown-input {
  border: 0;
  box-shadow: 0 0 0 0.25rem rgba(var(--bs-primary-rgb), 0.25);
}

.focus .ts-control {
  box-shadow: 0 0 0 0.25rem rgba(var(--bs-primary-rgb), 0.25);
}

.ts-wrapper.multi .ts-control > div.active {
    background: var(--bs-primary);
    color: #fff;
}



.ts-wrapper .item {
    display: inline-flex;
    align-items: center;
  }
  .ts-wrapper .item .update {
    color: inherit;
    text-decoration: none;
    vertical-align: middle;
    display: inline-block;
    padding: 0 6px;
    border-radius: 0 2px 2px 0;
    box-sizing: border-box;
  }
  .ts-wrapper .item .update:hover {
    background: rgba(0, 0, 0, 0.05);
  }
  .ts-wrapper.disabled .item .update:hover {
    background: none;
  }
  .ts-wrapper .update-single {
    position: absolute;
    right: 0;
    top: 0;
    font-size: 23px;
  }

  .ts-wrapper:not(.rtl) .item {
    padding-right: 0 !important;
  }
  .ts-wrapper:not(.rtl) .item .update {
    border-left: 1px solid #0073bb;
    margin-left: 6px;
  }
  .ts-wrapper:not(.rtl) .item.active .update {
    border-left-color: #00578d;
  }
  .ts-wrapper:not(.rtl).disabled .item .update {
    border-left-color: #aaaaaa;
  }

  .ts-wrapper.rtl .item {
    padding-left: 0 !important;
  }
  .ts-wrapper.rtl .item .update {
    border-right: 1px solid #0073bb;
    margin-right: 6px;
  }
  .ts-wrapper.rtl .item.active .update {
    border-right-color: #00578d;
  }
  .ts-wrapper.rtl.disabled .item .update {
    border-right-color: #aaaaaa;
  }

  .ts-wrapper.multi.disabled .ts-control [data-value], .ts-wrapper.multi.disabled .ts-control [data-value] .update {
    border-color: #e6e6e6;
  }
  .ts-wrapper.multi.disabled .ts-control [data-value] .update {
    background: none;
  }


  .plugin-clear_button .clear-button {
    color: #000 !important;
    border: none !important;
    opacity: 100% !important;
    position: absolute;
    top: 50%;
    transform: translateY(-50%);
    right: calc(8px - 6px);
    margin-right: 0 !important;
    background: transparent !important;
    transition: opacity 0.5s;
    cursor: pointer;
}
