{% comment %}
Renders the header for an option group.
{% endcomment %}
optgroup_header: function(data, escape) {
    return '<div class="optgroup-header" role="presentation">' + escape(data.label) + '</div>';
},
