{% comment %}
Renders the Clear Button plugin's HTML.
{% endcomment %}
{% load i18n %}

{% block code %}
html: function(data){
    return `<div class="${data.className}"
                title="${data.title}"
                role="button"
                aria-label="{% translate 'Clear selection' %}"
                tabindex="0">&times;</div>`;
},
{% endblock code %}
